SentenceGraph
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

## Install

``` sh
pip install SentenceGraph
```

## How to use

Fill me in please! Don’t forget code examples:

``` python
from SentenceGraph.core import SentenceGraph, Format
```

``` python
sentenceGraph = SentenceGraph()
```

``` python
sentences = ['This framework generates embeddings for each input sentence',
    'Sentences are passed as a list of string.', 
    'The quick brown fox jumps over the lazy dog.']
```

``` python
sim_graph = sentenceGraph.createGraph(sentences)
sim_graph
```

You can also return a graph matrix in different formats.

``` python
sim_graph = sentenceGraph.createGraph(sentences, format=Format.Numpy)
sim_graph
```
